<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @currentChange="handleCurrentChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="standardBindTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
      <!--检测标准详情-->
      <testStandardDialog
        :currshowlist.sync="showStandard"
        :paramTemplateObj="standardParamObj"
        :isDefaultSelect="isDefaultSelect"
        :isShowButton="isShowButton"
      />
    </basic-container>
  </div>
</template>
<script>
import { fetchList, delObj } from '@/api/quality/standardbind'
import ttable from '@/views/common/ztt-table.vue'
import TableForm from './standardbind-form'
import testStandardDialog from '@/views/common/teststandardradio'
import { mapGetters } from 'vuex'

export default {
  data() {
    return {
      ajaxFun: fetchList,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: true,
        url: '/mes/testStandardBinding/uploadExcel'
      },
      prelang: 'standardBind',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: false, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 零件号
          {
            minWidth: '140',
            prop: 'partNo',
            label: '零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 零件名称
          {
            minWidth: '120',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 工序
          {
            minWidth: '120',
            prop: 'operationName',
            label: '工序',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 标准编号
          {
            minWidth: '120',
            prop: 'standardNo',
            label: '标准编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.showStandardNo }
          },
          // 标准名称
          {
            minWidth: '120',
            prop: 'standardName',
            label: '标准名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false,
      showStandard: false,
      standardParamObj: {},
      isDefaultSelect: false,
      isShowButton: true
    }
  },
  components: {
    ttable,
    TableForm,
    testStandardDialog
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.standardBindTable.getDataList()
    },
    handleCurrentChange(row) {},
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 展示检测标准
    showStandardNo(row) {
      this.showStandard = true
      this.standardParamObj = { standardNo: row.standardNo }
      this.isDefaultSelect = true
      this.isShowButton = false
    },
    // 删除工作站点
    deleteHandle(row) {
      this.$confirm('是否确认删除标准绑定为' + row.standardName, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    }
  }
}
</script>
